@@ -36,7 +36,7 @@ typedef enum {
 
 #define FORMATS "hex", "dec", "dot"
 
-#define VERSION_NUMBER	"1.1.0"
+#define VERSION_NUMBER	"1.1.1"
 
 const char * const MAINTAINER = "Peter Pentchev <roam@ringlet.net>";
 const char * const VERSION =
@@ -173,7 +173,7 @@ int main(const int argc, char * const argv[])
 	else
 	{
 		for(uint32_t current = start; current <= end; current += increment) 
-		{	if(!exception_flag || !except(&current, octet))
+		{	if(!exception_flag || !except(&current, octet, increment))
 			{
 				switch(format)
 				{
